@@ -1,5 +1,26 @@
 <?php
 
+/*
+ * This file is part of pgFouine.
+ * 
+ * pgFouine - a PostgreSQL log analyzer
+ * Copyright (c) 2005-2006 Guillaume Smet
+ *
+ * pgFouine is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * pgFouine is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with pgFouine; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 require_once('lib/common.lib.php');
 require_once('base.lib.php');
 
@@ -11,6 +32,10 @@ class GenericLogReader {
 	var $lineParsedCounter = 0;
 	var $timeToParse;
 	
+	var $firstLineTimestamp;
+	var $lastLineTimestamp;
+	
+	var $reportAggregators = array();
 	var $listeners = array();
 	
 	function GenericLogReader($fileName, $lineParserName, $accumulatorName) {
@@ -18,10 +43,20 @@ class GenericLogReader {
 		$this->lineParserName = $lineParserName;
 		$this->accumulatorName = $accumulatorName;
 	}
+	
+	function addReportAggregator(& $reportAggregator) {
+		$this->reportAggregators[] =& $reportAggregator;
+	}
+	
+	function & getReportAggregators() {
+		return $this->reportAggregators;
+	}
 
 	function parse() {
 		global $lineParsedCounter;
 		
+		$this->prepare();
+		
 		$startTimestamp = time();
 		
 		$accumulator = new $this->accumulatorName;
@@ -29,10 +64,8 @@ class GenericLogReader {
 		
 		foreach(array_keys($this->listeners) AS $listenerName) {
 			$listener =& $this->listeners[$listenerName];
-			if(is_a($listener, 'QueryListener')) {
-				$accumulator->addQueryListener($listener);
-			} else {
-				$accumulator->addErrorListener($listener);
+			foreach($listener->getSubscriptions() AS $eventType) {
+				$accumulator->addListener($eventType, $listener);
 			}
 		}
 		
@@ -57,10 +90,18 @@ class GenericLogReader {
 		
 		$currentTimestamp = time();
 		while (!feof($filePointer)) {
+			$text = rtrim(fgets($filePointer), "\r\n");
+			if(empty($text)) {
+				continue;
+			}
 			$lineParsedCounter ++;
-			$text = fgets($filePointer);
+			
 			$line =& $lineParser->parse($text);
 			if($line) {
+				if(!isset($this->firstLineTimestamp)) {
+					$this->firstLineTimestamp = $line->getTimestamp();
+				}
+				$this->lastLineTimestamp = $line->getTimestamp();
 				$accumulator->append($line);
 			}
 			if($lineParsedCounter % 100000 == 0) {
@@ -90,6 +131,24 @@ class GenericLogReader {
 		}
 	}
 	
+	function output() {
+		for($i = 0; $i < count($this->reportAggregators); $i++) {
+			$this->reportAggregators[$i]->output();
+		}
+	}
+	
+	function prepare() {
+		$needs = array();
+		
+		for($i = 0; $i < count($this->reportAggregators); $i++) {
+			$needs = array_merge($needs, $this->reportAggregators[$i]->getNeeds());
+		}
+		$needs = array_unique($needs);
+		foreach($needs AS $need) {
+			$this->addListener($need);
+		}
+	}
+	
 	function getLineParsedCounter() {
 		return $this->lineParsedCounter;
 	}
@@ -101,10 +160,11 @@ class GenericLogReader {
 	
 	function & getListener($listenerName) {
 		if(isset($this->listeners[$listenerName])) {
-			return $this->listeners[$listenerName];
+			$listener =& $this->listeners[$listenerName];
 		} else {
-			return false;
+			$listener = false;
 		}
+		return $listener;
 	}
 	
 	function getFileName() {
@@ -118,6 +178,14 @@ class GenericLogReader {
 	function getLineParsedCount() {
 		return $this->lineParsedCounter;	
 	}
+	
+	function getFirstLineTimestamp() {
+		return $this->firstLineTimestamp;
+	}
+	
+	function getLastLineTimestamp() {
+		return $this->lastLineTimestamp;
+	}
 }
 
 ?>
\ No newline at end of file
