@@ -25,7 +25,10 @@ class PostgreSQLErrorLine extends PostgreSQLLogLine {
 	var $ignore = false;
 
 	function & getLogObject(& $logStream) {
-		$error = new ErrorLogObject($logStream->getUser(), $logStream->getDb(), $this->text);
+		$database = $this->database ? $this->database : $logStream->getDatabase();
+		$user = $this->user ? $this->user : $logStream->getUser();
+		
+		$error = new ErrorLogObject($user, $database, $this->text);
 		$error->setContextInformation($this->timestamp, $this->commandNumber);
 		
 		return $error;
