@@ -22,10 +22,9 @@
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-define('VERSION', '0.5.99');
+define('VERSION', '0.6');
 
 ini_set('max_execution_time', 18000);
-ini_set('memory_limit', '128M');
 
 if(strpos(phpversion(), '4.4') === 0) {
 	error_reporting(E_ALL - E_NOTICE);
@@ -51,7 +50,7 @@ function usage($error = false) {
   -                                      read the log from stdin instead of -file
   -top <n>                               number of queries in lists. Default is 20.
   -format <format>                       output format: html, html-with-graphs or text. Default is html.
-  -logtype <logtype>                     log type: syslog or stderr. Default is stderr.
+  -logtype <logtype>                     log type: syslog or stderr. Default is syslog.
                                           for stderr, you have to use the following log_line_prefix: \'%t [%p]: [%l-1] \'
   -report [outputfile=]<block1,block2>   list of report blocks separated by a comma
                                          report blocks can be: overall, hourly, bytype, slowest, n-mosttime,
@@ -64,6 +63,8 @@ function usage($error = false) {
   -database <database>                   consider only queries on this database
   -user <user>                           consider only queries executed by this user
   -title <title>                         define the title of the reports
+  -syslogident <ident>                   PostgreSQL syslog identity. Default is postgres.
+  -memorylimit <n>                       PHP memory limit in MB. Default is 128.
   -debug                                 debug mode
   -profile                               profile mode
   -help                                  this help
@@ -128,6 +129,13 @@ for($i = 0; $i < $argvCount; $i++) {
 	}
 }
 
+if(isset($options['memorylimit']) && ((int) $options['memorylimit']) > 0) {
+	$memoryLimit = (int) $options['memorylimit'];
+} else {
+	$memoryLimit = 128;
+}
+ini_set('memory_limit', $memoryLimit.'M');
+
 if(!defined('CONFIG_STDIN')) {
 	define('CONFIG_STDIN', false);
 }
@@ -229,6 +237,9 @@ if(isset($options['format'])) {
 			if(!function_exists('imagegd2')) {
 				usage('HTML with graphs format requires GD2 library and extension');
 			}
+			if(!function_exists('imagettfbbox')) {
+				usage('HTML with graphs format requires Freetype support');
+			}
 			if(!$outputToFiles) {
 				usage('you need to define an output file to use HTML with graphs format (use -report outputfile=block1,block2,...)');
 			}
@@ -303,6 +314,12 @@ if(CONFIG_FROM_TIMESTAMP || CONFIG_TO_TIMESTAMP) {
 	define('CONFIG_TIMESTAMP_FILTER', false);
 }
 
+if(isset($options['syslogident'])) {
+	define('CONFIG_SYSLOG_IDENTITY', $options['syslogident']);
+} else {
+	define('CONFIG_SYSLOG_IDENTITY', 'postgres');
+}
+
 $logReader = new GenericLogReader($filePath, $parser, 'PostgreSQLAccumulator');
 
 foreach($reports AS $report) {
